Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
/ private / var / folders / 6j / khn0mcrj35d1k3yylpl8zl080000gn / T / pytest-of-ned / pytest-163 / popen-gw3 / t90 / othersrc / other.py | (no class) |  | 1 | 0 | 0 |  | 100%
here.py | (no class) |  | 4 | 1 | 0 |  | 75%
Total |  |  | 5 | 1 | 0 |  | 80%

No items found using the specified filter.